..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Complex Recursive Problems
--------------------------

In the previous sections we looked at some problems that are relatively
easy to solve and some graphically interesting problems that can help
us gain a mental model of what is happening in a recursive algorithm. In
this and the following sections we will look at some problems that are really difficult to
solve using an iterative programming style but are very elegant and easy
to solve using recursion. We will finish up by looking at a deceptive
problem that at first looks like it has an elegant recursive solution
but in fact does not.
